==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'عرض الفوارق',

	// D
	'diff_para_ajoute' => 'فقرة مضافة',
	'diff_para_deplace' => 'فقرة منقولة',
	'diff_para_supprime' => 'فقرة محذوفة',
	'diff_texte_ajoute' => 'نص مضاف',
	'diff_texte_deplace' => 'نص منقول',
	'diff_texte_supprime' => 'نص محذوف',
	'differences_versions' => 'الفوارق بين الإصدار رقم @id_version@ والإصدار رقم @id_diff@',

	// I
	'icone_restaurer_version' => 'استرجاع الإصدار رقم @version@',
	'icone_suivi_revisions' => 'متابعة التعديلات',
	'info_1_revision' => 'تعديل واحد',
	'info_aucune_revision' => 'لا يوجد تعديلات',
	'info_historique' => 'التعديلات:',
	'info_historique_lien' => 'عرض التعديلات',
	'info_historique_titre' => 'متابعة التعديلات',
	'info_nb_revisions' => '@nb@ تعديل',

	// L
	'label_choisir_id_version' => 'تحديد الإصدارات للمقارنة',
	'label_config_revisions_objets' => 'على اي عناصر يجب تفعيل التعديلات:',

	// M
	'message_valider_recuperer_version' => 'التصديق على الاستمارة للعودة الى هذا الإصدار',

	// O
	'objet_editorial' => 'عنصر',

	// P
	'plugin_update' => 'تحديث ملحق «التعديلات» الى الإصدار @version@.',

	// T
	'titre_form_revisions_objets' => 'تفعيل التعديلات',
	'titre_restaurer_version' => 'استرجاع إصدار',
	'titre_revisions' => 'التعديلات',

	// V
	'version_deplace_rubrique' => 'منقول من <b>«@from@»</b> الى <b>«@to@»</b>.',
	'version_initiale' => 'الاصدار الاصلي',
	'voir_differences' => 'عرض الفوارق',
	'voir_mes_revisions' => 'تعديلاتي',
	'voir_revisions' => 'عرض التعديلات (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'كل التعديلات'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=ar
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'عرض الفوارق',

	// D
	'diff_para_ajoute' => 'فقرة مضافة',
	'diff_para_deplace' => 'فقرة منقولة',
	'diff_para_supprime' => 'فقرة محذوفة',
	'diff_texte_ajoute' => 'نص مضاف',
	'diff_texte_deplace' => 'نص منقول',
	'diff_texte_supprime' => 'نص محذوف',
	'differences_versions' => 'الفوارق بين الإصدار رقم @id_version@ والإصدار رقم @id_diff@',

	// I
	'icone_restaurer_version' => 'استرجاع الإصدار رقم @version@',
	'icone_suivi_revisions' => 'متابعة التعديلات',
	'info_1_revision' => 'تعديل واحد',
	'info_aucune_revision' => 'لا يوجد تعديلات',
	'info_historique' => 'التعديلات:',
	'info_historique_lien' => 'عرض التعديلات',
	'info_historique_titre' => 'متابعة التعديلات',
	'info_nb_revisions' => '@nb@ تعديل',

	// L
	'label_choisir_id_version' => 'تحديد الإصدارات للمقارنة',
	'label_config_revisions_objets' => 'على اي عناصر يجب تفعيل التعديلات:',

	// M
	'message_valider_recuperer_version' => 'التصديق على الاستمارة للعودة الى هذا الإصدار',

	// O
	'objet_editorial' => 'عنصر',

	// P
	'plugin_update' => 'تحديث ملحق «التعديلات» الى الإصدار @version@.',

	// T
	'titre_form_revisions_objets' => 'تفعيل التعديلات',
	'titre_restaurer_version' => 'استرجاع إصدار',
	'titre_revisions' => 'التعديلات',

	// V
	'version_deplace_rubrique' => 'منقول من <b>«@from@»</b> الى <b>«@to@»</b>.',
	'version_initiale' => 'الاصدار الاصلي',
	'voir_differences' => 'عرض الفوارق',
	'voir_mes_revisions' => 'تعديلاتي',
	'voir_revisions' => 'عرض التعديلات (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'كل التعديلات',
];
